@@ -151,9 +151,6 @@ void mex_define_copiers(FILE* fp, const char* name)
   if( (strcmp(name, "uint32_t") == 0 ) && ( mw_use_uint32_t == 0 ) ) return;
   if( (strcmp(name, "uint64_t") == 0 ) && ( mw_use_uint64_t == 0 ) ) return;
 
-  if( (strcmp(name, "longlong") == 0 ) && ( mw_use_longlong == 0 ) ) return;
-  if( (strcmp(name, "ulonglong") == 0 ) && ( mw_use_ulonglong == 0 ) ) return;
-
   if( (strcmp(name, "ulong") == 0 ) && ( mw_use_ulong == 0 ) ) return;
   if( (strcmp(name, "uint") == 0 ) && ( mw_use_uint == 0 ) ) return;
   if( (strcmp(name, "ushort") == 0 ) && ( mw_use_ushort == 0 ) ) return;
